# SMQTK
![Build Status](https://travis-ci.org/Kitware/SMQTK.svg?branch=master)

[![Documentation Status](https://readthedocs.org/projects/smqtk/badge/?version=latest)](https://smqtk.readthedocs.io/en/latest/?badge=latest)

## Intent
Social Multimedia Query ToolKit aims to provide a simple and easy to use API for:

* Scalable data structure interfaces and implementations, with a focus on those relevant for machine learning.
* Algorithm interfaces and implementations of machine learning algorithms with a focus on media-based functionality.
* High-level applications and utilities for working with available algorithms and data structures for specific purposes.

Through these features, users and developers are able to access various machine learning algorithms and techniques to use over different types of data for different high level applications.
Examples of high level applications may include being able to search a media corpus for similar content based on a query, or providing a content-based relevancy feedback interface for a web application.

## Documentation

Documentation for SMQTK is maintained at [ReadtheDocs](http://smqtk.readthedocs.org), including [build instructions](http://smqtk.readthedocs.org/en/latest/building.html) and [examples](http://smqtk.readthedocs.org/en/latest/examples/overview.html).

